from django.shortcuts import render_to_response

class DuctTapeMiddleware():
    def process_request(self, request):
        """Block some IPs in name of "Fair net"
        """
        ips = []
        ips.extend("80.118.139.%s" % x for x in range(160, 192))
        ips.extend("62.160.71.%s" % x for x in range(0, 256))
        ips.extend("84.223.174.%s" % x for x in range(48, 64))
        if request.META['REMOTE_ADDR'] in ips:
            return render_to_response("neutralityFR/sorry.html", {})



#!/usr/bin/env python
import sys, os

from setuptools import setup, find_packages

version = '0.1.1'

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
CHANGES = open(os.path.join(here, 'CHANGES.txt')).read()

setup(
    name='django-neutralityFR',
    version=version,
    description="Middleware Django anti-netneutrality to give an example to some people.",
    long_description=README + '\n\n' +  CHANGES,
    classifiers=[
     "Programming Language :: Python",
     "Framework :: Django",
     "License :: OSI Approved :: MIT License",
    # Get strings from http://pypi.python.org/pypi?%3Aaction=list_classifiers
    ],
    keywords='',
    author='Johan Charpentier',
    author_email='cyberj@arcagenis.org',
    url='https://github.com/cyberj/django-neutralityFR',
    license='MIT',
    packages=find_packages(exclude=['ez_setup', 'examples', 'tests']),
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        # -*- Extra requirements: -*-
    ],
    entry_points="""
    # -*- Entry points: -*-
    """,
    )
